@@ -2,12 +2,20 @@ package Aspect::Advice;
 
 use strict;
 use warnings;
+use Carp ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 
 sub new {
 	my $class = shift;
-	my $self  = bless { @_ }, $class;
+	my $self  = bless {
+		@_,
+		installed => 0,
+	}, $class;
+
+	# Validate the advice and pointcut combination
+	my $error = $self->_validate;
+	Carp::croak($error) if defined $error;
 
 	# Install and save the lexical hook
 	$self->{hook} = $self->_install;
@@ -27,10 +35,58 @@ sub lexical {
 	$_[0]->{lexical};
 }
 
+sub installed {
+	$_[0]->{installed};
+}
+
 sub DESTROY {
 	$_[0]->{hook}->() if $_[0]->{hook};
 }
 
+
+
+
+
+######################################################################
+# Installation Internals
+
+sub _install {
+	my $class = ref $_[0] || $_[0];
+	die("Method '_install' is not implemented by class '$class'");
+}
+
+sub _validate {
+	my $self = shift;
+
+	# The use of more than one highest rule in a pointcut is not supported
+	if ( $self->pointcut->match_contains('Aspect::Pointcut::Highest') > 1 ) {
+		return "Multiple highest pointcut use is not yet supported";
+	}
+
+	return;
+}
+
+
+
+
+
+######################################################################
+# Optional XS Acceleration
+
+BEGIN {
+	local $@;
+	eval <<'END_PERL';
+use Class::XSAccessor 1.08 {
+	replace => 1,
+	getters => {
+		'code'     => 'code',
+		'pointcut' => 'pointcut',
+		'lexical'  => 'lexical',
+	},
+};
+END_PERL
+}
+
 1;
 
 __END__
@@ -87,17 +143,7 @@ own lexical scope between the caller and callee, with a specific C<proceed>
 call required in your code to execute the target function. See
 L<Aspect::Advice::Around> for more information.
 
-Two more specialised variants of C<after> are also available.
-
-C<after_returning> is used to indicate code that should run following the
-function, but ignoring exceptions and allowing them to raise normally. See
-L<Aspect::Advice::AfterReturning> for more information.
-
-C<after_throwing> is used to indicate code that should run only when the
-target function throws an exception. See L<Aspect::Advice::AfterThrowing>
-for more information.
-
-Then the advice code is called, it is provided with an L<Advice::Point>
+When the advice code is called, it is provided with an L<Advice::Point>
 object which describes the context of the call to the target function, and
 allows you to change it.
 
