@@ -12,7 +12,7 @@ use Aspect::Hook         ();
 use Aspect::Advice       ();
 use Aspect::Point::After ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -28,7 +28,7 @@ sub _install {
 	# runtime checks instead of the original.
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
-	my $curried   = $pointcut->match_curry;
+	my $curried   = $pointcut->curry_runtime;
 	my $compiled  = $curried ? $curried->compiled_runtime : undef;
 	my $MATCH_RUN = $compiled ? '$compiled->()' : 1;
 
@@ -80,7 +80,7 @@ sub _install {
 				local \$_ = bless {
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
-					params       => \\\@_,
+					args         => \\\@_,
 					return_value => \$return,
 					exception    => \$\@,
 					pointcut     => \$pointcut,
@@ -92,10 +92,10 @@ sub _install {
 				}
 
 				# Execute the advice code
-				() = &\$code(\$_);
+				&\$code(\$_);
 
 				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
+				my \$exception = \$_->{exception};
 				die \$exception if \$exception;
 
 				# Get the (potentially) modified return value
@@ -112,59 +112,61 @@ sub _install {
 				local \$_ = bless {
 					sub_name     => \$name,
 					wantarray    => \$wantarray,
-					params       => \\\@_,
+					args         => \\\@_,
 					return_value => \$return,
 					exception    => \$\@,
 					pointcut     => \$pointcut,
 					original     => \$original,
 				}, 'Aspect::Point::After';
+
 				unless ( $MATCH_RUN ) {
 					return \$return unless \$_->{exception};
 					die \$_->{exception};
 				}
 
-				# Execute the advice code
-				my \$dummy = &\$code(\$_);
-
-				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
-				die \$exception if \$exception;
-
-				# Return the potentially-modified value
-				return \$_->{return_value};
-
-			} else {
-				eval {
-					Sub::Uplevel::uplevel(
-						2, \$original, \@_,
-					)
-				};
-
-				local \$_ = bless {
-					sub_name     => \$name,
-					wantarray    => \$wantarray,
-					params       => \\\@_,
-					return_value => undef,
-					exception    => \$\@,
-					pointcut     => \$pointcut,
-					original     => \$original,
-				}, 'Aspect::Point::After';
-				unless ( $MATCH_RUN ) {
-					return unless \$_->{exception};
-					die \$_->{exception};
-				}
-
 				# Execute the advice code
 				&\$code(\$_);
 
 				# Throw the same (or modified) exception
-				my \$exception = \$_->exception;
+				my \$exception = \$_->{exception};
 				die \$exception if \$exception;
 
-				return;
+				# Return the potentially-modified value
+				return \$_->{return_value};
+
 			}
+
+			eval {
+				Sub::Uplevel::uplevel(
+					2, \$original, \@_,
+				)
+			};
+
+			local \$_ = bless {
+				sub_name     => \$name,
+				wantarray    => \$wantarray,
+				args         => \\\@_,
+				return_value => undef,
+				exception    => \$\@,
+				pointcut     => \$pointcut,
+				original     => \$original,
+			}, 'Aspect::Point::After';
+			unless ( $MATCH_RUN ) {
+				return unless \$_->{exception};
+				die \$_->{exception};
+			}
+
+			# Execute the advice code
+			&\$code(\$_);
+
+			# Throw the same (or modified) exception
+			my \$exception = \$_->{exception};
+			die \$exception if \$exception;
+
+			return;
 		};
 END_PERL
+		$self->{installed}++;
 	}
 
 	# If this will run lexical we don't need a descoping hook
@@ -196,9 +198,12 @@ Aspect::Advice::After - Execute code after a function is called
       print STDERR "Called my function " . $_->sub_name . "\n";
   
       # Suppress exceptions AND alter the results to foo()
-      if ( $_->short_sub_name eq 'foo' ) {
-          $_->return_value(1) if $_->exception;
-          $_->return_value( $_->return_value + 1 );
+      if ( $_->short_name eq 'foo' ) {
+          if ( $_->exception ) {
+              $_->return_value(1);
+          } else {
+              $_->return_value( $_->return_value + 1 );
+          }
       }
   
   } call qr/^ MyModule::\w+ $/
@@ -206,17 +211,17 @@ Aspect::Advice::After - Execute code after a function is called
 =head1 DESCRIPTION
 
 The C<after> advice type is used to execute code after a function is called,
-regardless of whether or not the function returned normally or returned an
+regardless of whether or not the function returned normally or threw an 
 exception.
 
 The C<after> advice type should be used when you need to potentially make
 multiple different changes to the returned value or the thrown exception.
 
-If you only care about normally returned values you should use
-C<after_returning> (L<Aspect::Advice::AfterReturning>) instead.
+If you only care about normally returned values you should use C<returning> in
+the pointcut to exclude join points occuring due to exceptions.
 
-If you only care about handling exceptions you should use C<after_throwing>
-(L<Aspect::Advice::AfterThrowing>) instead.
+If you only care about handling exceptions you should use C<throwing> in the
+pointcut to exclude join points occuring due to normal return.
 
 =head1 AUTHORS
 
