@@ -11,7 +11,7 @@ use Aspect::Hook          ();
 use Aspect::Advice        ();
 use Aspect::Point::Before ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 our @ISA     = 'Aspect::Advice';
 
 sub _install {
@@ -20,18 +20,11 @@ sub _install {
 	my $code     = $self->code;
 	my $lexical  = $self->lexical;
 
-	# Special case.
-	# The method used by the Highest pointcut is incompatible
-	# with the goto optimisation used by the before() advice.
-	if ( $pointcut->match_contains('Aspect::Pointcut::Highest') ) {
-		Carp::croak("The highest pointcut is not currently supported by this advice");
-	}
-
 	# Get the curried version of the pointcut we will use for the
 	# runtime checks instead of the original.
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
-	my $curried   = $pointcut->match_curry;
+	my $curried   = $pointcut->curry_runtime;
 	my $compiled  = $curried ? $curried->compiled_runtime : undef;
 	my $MATCH_RUN = $compiled ? '$compiled->()' : 1;
 
@@ -77,21 +70,22 @@ sub _install {
 			local \$_ = bless {
 				sub_name     => \$name,
 				wantarray    => \$wantarray,
-				params       => \\\@_,
+				args         => \\\@_,
 				pointcut     => \$pointcut,
 				return_value => \$wantarray ? [ ] : undef,
 				original     => \$original,
 				proceed      => 1,
 			}, 'Aspect::Point::Before';
+
 			goto &\$original unless $MATCH_RUN;
 
 			# Array context needs some special return handling
 			if ( \$wantarray ) {
 				# Run the advice code
-				() = &\$code(\$_);
+				&\$code(\$_);
 
-				if ( \$_->proceed ) {
-					\@_ = \$_->params;
+				if ( \$_->{proceed} ) {
+					\@_ = \$_->args; ### Superfluous?
 					goto &\$original;
 				}
 
@@ -100,23 +94,17 @@ sub _install {
 			}
 
 			# Scalar and void have the same return handling.
-			# Just run the advice code differently.
-			if ( defined \$wantarray ) {
-				my \$dummy = &\$code(\$_);
-			} else {
-				&\$code(\$_);
-			}
+			&\$code(\$_);
 
 			# Do they want to shortcut?
-			unless ( \$_->proceed ) {
-				return \$_->{return_value};
-			}
+			return \$_->{return_value} unless \$_->{proceed};
 
 			# Continue onwards to the original function
-			\@_ = \$_->params;
+			\@_ = \$_->args; ### Superfluous?
 			goto &\$original;
 		};
 END_PERL
+		$self->{installed}++;
 	}
 
 	# If this will run lexical we don't need a descoping hook
@@ -129,6 +117,30 @@ END_PERL
 	return sub { $out_of_scope = 1 };
 }
 
+# Check for pointcut usage not supported by the advice type
+sub _validate {
+	my $self     = shift;
+	my $pointcut = $self->pointcut;
+
+	# The method used by the Highest pointcut is incompatible
+	# with the goto optimisation used by the before() advice.
+	if ( $pointcut->match_contains('Aspect::Pointcut::Highest') ) {
+		return 'The pointcut highest is not currently supported by before advice';
+	}
+
+	# Pointcuts using "throwing" are irrelevant in before advice
+	if ( $pointcut->match_contains('Aspect::Pointcut::Throwing') ) {
+		return 'The pointcut throwing is illegal when used by before advice';
+	}
+
+	# Pointcuts using "throwing" are irrelevant in before advice
+	if ( $pointcut->match_contains('Aspect::Pointcut::Returning') ) {
+		return 'The pointcut returning is illegal when used by before advice';
+	}
+
+	$self->SUPER::_validate(@_);
+}
+
 1;
 
 __END__
@@ -149,10 +161,15 @@ Aspect::Advice::Before - Execute code before a function is called
       print STDERR "Called my function " . $_->sub_name . "\n";
   
       # Shortcut calls to foo() to always be true
-      if ( $_->short_sub_name eq 'foo' ) {
-          $_->return_value(1);
+      if ( $_->short_name eq 'foo' ) {
+          return $_->return_value(1);
       }
   
+      # Add an extra flag to bar() but call as normal
+      if ( $_->short_name eq 'bar' ) {
+          $_->args( $_->args, 'flag' );
+      }
+
   } call qr/^ MyModule::\w+ $/
 
 =head1 DESCRIPTION
