@@ -3,11 +3,11 @@ package Aspect::Library::Listenable::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 
 sub new {
 	my $class = shift;
-	return bless { @_ }, $class;
+	bless { @_ }, $class;
 }
 
 sub AUTOLOAD {
