@@ -40,7 +40,7 @@ use Aspect::Pointcut::Or  ();
 use Aspect::Pointcut::And ();
 use Aspect::Pointcut::Not ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 
 use overload (
 	# Keep traditional Perl boolification and stringification
@@ -48,7 +48,7 @@ use overload (
 	'""'   => sub { ref $_[0] },
 
 	# Overload bitwise boolean operators to perform logical transformations.
-	'|'    => sub { Aspect::Pointcut::Or ->new( $_[0], $_[1] ) },
+	'|'    => sub { Aspect::Pointcut::Or->new(  $_[0], $_[1] ) },
 	'&'    => sub { Aspect::Pointcut::And->new( $_[0], $_[1] ) },
 	'!'    => sub { Aspect::Pointcut::Not->new( $_[0]        ) },
 
@@ -133,7 +133,7 @@ BEGIN {
 
 =head2 match_all
 
-  my @fully_resolved_function_names = $pointcut->match_all();
+  my @fully_resolved_function_names = $pointcut->match_all;
 
 The C<match_all> method is the primary compile-time function called on the
 pointcut model by the core Aspect library.
@@ -156,10 +156,11 @@ sub match_all {
 	my $self    = shift;
 	my @matches = ();
 
-	# Generate the compiled form of the weave-time function feature
-	my $compiled = $self->compiled_weave;
+	# Curry the pointcut and compile the weave-time function
+	my $curried  = $self->curry_weave;
+	my $compiled = $curried ? $self->compiled_weave : sub () { 1 };
 	unless ( $compiled ) {
-		die "Failed to generate filter ->compile_weave";
+		die "Failed to generate weave filter";
 	}
 
 	# Quick initial root package scan to remove the need
@@ -224,7 +225,7 @@ sub match_all {
 
 =head2 match_define
 
-  my $should_hook = $pointcut->match_define();
+  my $should_hook = $pointcut->match_define;
 
 At compile time, the only common factor in predicting the future state of
 a function call is the name of the function itself.
@@ -258,7 +259,7 @@ if a particular named function should be hooked as a potential join point.
 
 =cut
 
-# Most pointcut conditions always match, so default to that
+# Most pointcut conditions always match at weave time, so default to that
 sub compile_weave {
 	return 1;
 }
@@ -270,6 +271,8 @@ sub compiled_weave {
 	return eval "sub () { $code }";
 }
 
+=pod
+
 =head2 compile_runtime
 
 The C<compile_runtime> method generates a custom function that is used to test
@@ -293,28 +296,48 @@ sub compiled_runtime {
 
 =head2 match_contains
 
-  my $contains_any = $pointcut->match_contains('Aspect::Pointcut::Call');
+  my $calls = $pointcut->match_contains('Aspect::Pointcut::Call');
 
-The C<match_contains> method provides a convenience for the optimisation
-system which is used to check for the existance of a particular condition
-type anywhere within the pointcut object tree.
+The C<match_contains> method provides a convenience for the validation and
+optimisation systems. It is used to check for the existance of a particular
+condition type anywhere within the pointcut object tree.
 
-Returns true if the tree contains any conditions of that type, or false
-if not.
+Returns the number of instances of a particular pointcut type within the tree.
 
 =cut
 
 sub match_contains {
 	my $self = shift;
 	return 1 if $self->isa($_[0]);
-	return '';
+	return 0;
 }
 
 =pod
 
-=head2 match_curry
+=head2 match_always
 
-  my $optimized_pointcut = $raw_pointcut->match_curry();
+  my $always = $pointcut->match_contains('Aspect::Pointcut::Throwing');
+
+The C<match_always> method provides a convenience for the validation and
+optimisation systems. It is used to check that a particular condition type will
+be tested at least once for a matching join point, regardless of which path
+the match takes through branching pointcut logic.
+
+Returns true if an expression type is encounter at least once in all branches,
+or false if there is any branch path that can be taken in which the condition
+won't be encountered.
+
+=cut
+
+sub match_always {
+	die "CODE NOT IMPLEMENTED";
+}
+
+=pod
+
+=head2 curry_runtime
+
+  my $optimized_pointcut = $raw_pointcut->curry_runtime;
 
 In a production system, pointcut declarations can result in large and
 complex B<Aspect::Pointcut> object trees.
@@ -343,15 +366,52 @@ away to nothing, and no further testing needs to be done at run-time.
 
 =cut
 
-sub match_curry {
+sub curry_runtime {
 	my $class = ref $_[0] || $_[0];
-	die("Method 'match_curry' not implemented in class '$class'");
+	die("Method 'curry_runtime' not implemented in class '$class'");
+}
+
+=pod
+
+=head2 curry_weave
+
+The C<curry_weave> method is similar to the C<curry_runtime> method, except
+that instead of reducing the pointcut to only elements that are relevant at
+run-time, it reduces the pointcut to only elements that are relevant at weave
+time.
+
+By remove purely run-time elements, the compile weave test code is made both
+faster and more accurate (some complicated situations can occur when there is
+a L<Aspect::Pointcut::Not> in the tree).
+
+=cut
+
+sub curry_weave {
+	my $class = ref $_[0] || $_[0];
+	die("Method 'curry_weave' not implemented in class '$class'");
 }
 
 sub match_runtime {
 	return 1;
 }
 
+
+
+
+
+######################################################################
+# Optional XS Acceleration
+
+BEGIN {
+	local $@;
+	eval <<'END_PERL';
+use Class::XSAccessor::Array 1.08 {
+	replace => 1,
+	true    => [ 'compile_weave', 'match_runtime' ],
+};
+END_PERL
+}
+
 1;
 
 __END__
