@@ -2,14 +2,38 @@ package Aspect::Pointcut::And;
 
 use strict;
 use warnings;
-use Aspect::Pointcut        ();
 use Aspect::Pointcut::Logic ();
 
-our $VERSION = '0.96';
-our @ISA     = qw{
-	Aspect::Pointcut::Logic
-	Aspect::Pointcut
-};
+our $VERSION = '0.98';
+our @ISA     = 'Aspect::Pointcut::Logic';
+
+
+
+
+
+######################################################################
+# Constructor
+
+sub new {
+	my $class = shift;
+	my @parts = @_;
+
+	# Validate the pointcut subexpressions
+	foreach my $part ( @parts ) {
+		next if Params::Util::_INSTANCE($part, 'Aspect::Pointcut');
+		Carp::croak("Attempted to apply pointcut logic to non-pointcut '$part'");
+	}
+
+	# Collapse nested and statements at constructor time so we don't have
+	# to do so multiple times later on during currying.
+	while ( scalar grep { $_->isa('Aspect::Pointcut::And') } @parts ) {
+		@parts = map {
+			$_->isa('Aspect::Pointcut::And') ? @$_ : $_
+		} @parts;
+	}
+
+	$class->SUPER::new(@parts);
+}
 
 
 
@@ -121,14 +145,15 @@ sub compile_runtime {
 		return 1;
 	};
 }
-	
+
 sub match_contains {
-	my $self = shift;
-	return 1 if $self->isa($_[0]);
+	my $self  = shift;
+	my $type  = shift;
+	my $count = $self->isa($type) ? 1 : 0;
 	foreach my $child ( @$self ) {
-		return 1 if $child->match_contains($_[0]);
+		$count += $child->match_contains($type);
 	}
-	return '';
+	return $count;
 }
 
 sub match_runtime {
@@ -139,16 +164,28 @@ sub match_runtime {
 	return 0;
 }
 
-sub match_curry {
+sub curry_weave {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested ::And clauses
-	while ( scalar grep { $_->isa('Aspect::Pointcut::And') } @list ) {
-		@list = map {
-			$_->isa('Aspect::Pointcut::And') ? @$_ : $_
-		} @list;
-	}
+	# Curry down our children. Anything that is not relevant at weave
+	# time is considered to always match, but curries to null.
+	# In an AND scenario, any "always" match can be savely removed.
+	@list = grep { defined $_ } map { $_->curry_weave } @list;
+
+	# If none are left, curry us away to nothing
+	return unless @list;
+
+	# If only one remains, curry us away to just that child
+	return $list[0] if @list == 1;
+
+	# Create our clone to hold the curried subset
+	return ref($self)->new( @list );
+}
+
+sub curry_runtime {
+	my $self = shift;
+	my @list = @$self;
 
 	# Should we strip out the call pointcuts
 	my $strip = shift;
@@ -172,9 +209,9 @@ sub match_curry {
 	@list = grep { defined $_ } map {
 		$_->isa('Aspect::Pointcut::Call')
 		? $strip
-			? $_->match_curry($strip)
+			? $_->curry_runtime($strip)
 			: $_
-		: $_->match_curry($strip)
+		: $_->curry_runtime($strip)
 	} @list;
 
 	# If none are left, curry us away to nothing
