@@ -6,7 +6,7 @@ use Carp             ();
 use Params::Util     ();
 use Aspect::Pointcut ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 our @ISA     = 'Aspect::Pointcut';
 
 use constant ORIGINAL     => 0;
@@ -88,10 +88,15 @@ sub match_runtime {
 	return 0;
 }
 
+# Call pointcuts are the primary thing used at weave time
+sub curry_weave {
+	return $_[0];
+}
+
 # Call pointcuts curry away to null, because they are the basis
 # for which methods to hook in the first place. Any method called
 # at run-time has already been checked.
-sub match_curry {
+sub curry_runtime {
 	return;
 }
 
@@ -105,6 +110,26 @@ sub compile_runtime {
 	$_[0]->[5];
 }
 
+
+
+
+
+######################################################################
+# Optional XS Acceleration
+
+BEGIN {
+	local $@;
+	eval <<'END_PERL';
+use Class::XSAccessor::Array 1.08 {
+	replace => 1,
+	getters => {
+		'compile_weave'   => 4,
+		'compile_runtime' => 5,
+	},
+};
+END_PERL
+}
+
 1;
 
 __END__
