@@ -6,9 +6,9 @@ use Carp                   ();
 use Params::Util           ();
 use Aspect::Pointcut       ();
 use Aspect::Pointcut::Call ();
-use Aspect::AdviceContext  ();
+use Aspect::Point::Static  ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 our @ISA     = 'Aspect::Pointcut';
 
 use constant KEY  => 0;
@@ -23,13 +23,16 @@ use constant SPEC => 2;
 
 sub new {
 	my $class = shift;
-	unless ( Params::Util::_IDENTIFIER($_[0]) ) {
+
+	# Check and default the cflow key
+	my $key = @_ > 1 ? shift : 'enclosing';
+	unless ( Params::Util::_IDENTIFIER($key) ) {
 		Carp::croak('Invalid runtime context key');
 	}
 
 	# Generate it via call
-	my $call = Aspect::Pointcut::Call->new($_[1]);
-	return bless [ $_[0], @$call ], $class;
+	my $call = Aspect::Pointcut::Call->new(shift);
+	return bless [ $key, @$call ], $class;
 }
 
 
@@ -39,9 +42,15 @@ sub new {
 ######################################################################
 # Weaving Methods
 
+# The cflow pointcut is currently of no value at weave time, because it is
+# actually implemented as something closer to cflowbelow.
+sub curry_weave {
+	return;
+}
+
 # The cflow pointcuts do not curry at all.
 # So they don't need to clone, and can be used directly.
-sub match_curry {
+sub curry_runtime {
 	return $_[0];
 }
 
@@ -63,12 +72,11 @@ sub compile_runtime {
 			last;
 		}
 		return 0 unless $caller;
-		my $class   = (ref $_ or 'Aspect::AdviceContext');
-		my $context = $class->new(
+		my $context = bless {
 			sub_name => $caller->{sub_name},
 			pointcut => $_->{pointcut},
-			params   => $caller->{params},
-		);
+			args     => $caller->{args},
+		}, 'Aspect::Point::Static';
 		$_->{$self->[KEY]} = $context;
 		return 1;
 	};
@@ -80,16 +88,16 @@ sub caller_info {
 	package DB;
 
 	my %call_info;
-	@call_info{qw(
+	@call_info{ qw(
 		calling_package
 		sub_name
 		has_params
-	)} = (CORE::caller($level))[0, 3, 4];
+	) } = (CORE::caller($level))[0, 3, 4];
 
 	return defined $call_info{calling_package}
 		? {
 			%call_info,
-			params => [
+			args => [
 				$call_info{has_params} ? @DB::args : ()
 			],
 		} : 0;
