@@ -2,11 +2,13 @@ package Aspect::Pointcut::Highest;
 
 use strict;
 use warnings;
-use Carp             ();
-use Params::Util     ();
-use Aspect::Pointcut ();
+use Carp                               ();
+use Scalar::Util                       ();
+use Params::Util                       ();
+use Aspect::Guard                      ();
+use Aspect::Pointcut                   ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 our @ISA     = 'Aspect::Pointcut';
 
 
@@ -27,10 +29,15 @@ sub new {
 ######################################################################
 # Weaving Methods
 
+# The highest pointcut is a run-time only pointcut
+sub curry_weave {
+	return;
+}
+
 # Call pointcuts curry away to null, because they are the basis
 # for which methods to hook in the first place. Any method called
 # at run-time has already been checked.
-sub match_curry {
+sub curry_runtime {
 	bless [ 0 ], $_[0];
 }
 
@@ -44,19 +51,11 @@ sub match_curry {
 sub compile_runtime {
 	my $depth = 0;
 	return sub {
-		my $cleanup  = sub { $depth-- };
-		bless $cleanup, 'Aspect::Pointcut::Highest::Cleanup';
-		$_->{highest} = $cleanup;
+		$_->{highest} = Aspect::Guard->new( sub { $depth-- } );
 		return ! $depth++;
 	};
 }
 
-package Aspect::Pointcut::Highest::Cleanup;
-
-sub DESTROY {
-	$_[0]->();
-}
-
 1;
 
 __END__
