@@ -1,11 +1,15 @@
 package Aspect::Pointcut::Logic;
 
-# A mixable role for logic pointcuts
+# A base class for logic pointcuts
 
 use strict;
 use warnings;
+use Carp             ();
+use Params::Util     ();
+use Aspect::Pointcut ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
+our @ISA     = 'Aspect::Pointcut';
 
 sub match_runtime {
 	return 0;
