@@ -2,14 +2,38 @@ package Aspect::Pointcut::Or;
 
 use strict;
 use warnings;
-use Aspect::Pointcut        ();
 use Aspect::Pointcut::Logic ();
 
-our $VERSION = '0.96';
-our @ISA     = qw{
-	Aspect::Pointcut::Logic
-	Aspect::Pointcut
-};
+our $VERSION = '0.98';
+our @ISA     = 'Aspect::Pointcut::Logic';
+
+
+
+
+
+######################################################################
+# Constructor
+
+sub new {
+	my $class = shift;
+	my @parts = @_;
+
+	# Validate the pointcut subexpressions
+	foreach my $part ( @parts ) {
+		next if Params::Util::_INSTANCE($part, 'Aspect::Pointcut');
+		Carp::croak("Attempted to apply pointcut logic to non-pointcut '$part'");
+	}
+
+	# Collapse nested or statements at constructor time so we don't have
+	# to do so multiple times later on during currying.
+	while ( scalar grep { $_->isa('Aspect::Pointcut::Or') } @parts ) {
+		@parts = map {
+			$_->isa('Aspect::Pointcut::Or') ? @$_ : $_
+		} @parts;
+	}
+
+	$class->SUPER::new(@parts);
+}
 
 
 
@@ -103,12 +127,12 @@ sub compile_runtime {
 }
 
 sub match_contains {
-	my $self = shift;
-	return 1 if $self->isa($_[0]);
+	my $self  = shift;
+	my $count = $self->isa($_[0]) ? 1 : 0;
 	foreach my $child ( @$self ) {
-		return 1 if $child->match_contains($_[0]);
+		$count += $child->match_contains($_[0]);
 	}
-	return '';
+	return $count;
 }
 
 sub match_runtime {
@@ -119,17 +143,32 @@ sub match_runtime {
 	return 0;
 }
 
-sub match_curry {
+sub curry_weave {
 	my $self = shift;
 	my @list = @$self;
 
-	# Collapse nested logical clauses
-	while ( scalar grep { $_->isa('Aspect::Pointcut::Or') } @list ) {
-		@list = map {
-			$_->isa('Aspect::Pointcut::Or') ? @$_ : $_
-		} @list;
+	# Curry down our children. Any null element always matches, and
+	# therefore in an OR scenario the entire expression always matches.
+	my @or = ();
+	foreach my $child ( @list ) {
+		my $curried = $child->curry_weave or return;
+		push @or, $curried;
 	}
 
+	# If none are left, curry us away to nothing
+	return unless @or;
+
+	# If only one remains, curry us away to just that child
+	return $list[0] if @or == 1;
+
+	# Create our clone to hold the curried subset
+	return ref($self)->new(@or);
+}
+
+sub curry_runtime {
+	my $self = shift;
+	my @list = @$self;
+
 	# Should we strip out the call pointcuts
 	my $strip = shift;
 	unless ( defined $strip ) {
@@ -152,9 +191,9 @@ sub match_curry {
 	@list = grep { defined $_ } map {
 		$_->isa('Aspect::Pointcut::Call')
 		? $strip
-			? $_->match_curry($strip)
+			? $_->curry_runtime($strip)
 			: $_
-		: $_->match_curry($strip)
+		: $_->curry_runtime($strip)
 	} @list;
 
 	# If none are left, curry us away to nothing
