@@ -5,7 +5,7 @@ use warnings;
 use Carp             ();
 use Aspect::Pointcut ();
 
-our $VERSION = '0.96';
+our $VERSION = '0.98';
 our @ISA     = 'Aspect::Pointcut';
 
 use constant VOID   => 1;
@@ -43,8 +43,13 @@ sub new {
 ######################################################################
 # Weaving Methods
 
+# This is a run-time only pointcut of no value at weave time
+sub curry_weave {
+	return;
+}
+
 # For wantarray pointcuts we keep the original
-sub match_curry {
+sub curry_runtime {
 	return $_[0];
 }
 
@@ -52,6 +57,25 @@ sub compile_runtime {
 	$_[0]->[1];
 }
 
+
+
+
+
+######################################################################
+# Optional XS Acceleration
+
+BEGIN {
+	local $@;
+	eval <<'END_PERL';
+use Class::XSAccessor::Array 1.08 {
+	replace => 1,
+	getters => {
+		'compile_runtime' => 1,
+	},
+};
+END_PERL
+}
+
 1;
 
 __END__
